import { NextFunction, Request, Response } from 'express';
import { CreateItemsDto } from '../dtos/items.dto';
import { Items } from '../interfaces/items.interface';
import itemsService from '../services/items.service';
import itemsModel from '../models/item.model';
interface MulterRequest extends Request {
  file: any;
}
class ItemsController {
  public itemsService = new itemsService();

  public findAllItems = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const findAllItemsData: Items[] = await this.itemsService.findAllItems();

      res.status(200).json({ data: findAllItemsData, message: 'findAll' });
    } catch (error) {
      next(error);
    }
  };

  public findItemsById = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const itemsId: string = req.params.id;
      const findOneItemsData: Items = await this.itemsService.findItemsById(itemsId);

      res.status(200).json({ data: findOneItemsData, message: 'findOne' });
    } catch (error) {
      next(error);
    }
  };

  public findItemsByResourcesId = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const resourcesId: string = req.params.resourcesId;
      const findItemsData: Items[] = await this.itemsService.findItemsByResourcesId(resourcesId);

      res.status(200).json({ data: findItemsData, message: 'findOne' });
    } catch (error) {
      next(error);
    }
  };

  public createItems = async (req: MulterRequest, res: Response, next: NextFunction) => {
    try {
    const resourcesId = req.body.resourcesId;
    const topic = req.body.topic;
    const details = req.body.details;
    const label = req.body.label;
    let image = "";
    if (req.file !== undefined) {
        image = req.file.path
    }
    let newItems = new itemsModel({
        resourcesId, topic, details, label, image
  })

      const createItemsData: Items = await this.itemsService.createItems(newItems);

      res.status(201).json({ data: createItemsData, message: 'created' });
    } catch (error) {
      next(error);
    }
  };

  public updateItems = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const itemsId: string = req.params.id;
      const itemsData: CreateItemsDto = req.body;
      const updateItemsData: Items = await this.itemsService.updateItems(itemsId, itemsData);

      res.status(200).json({ data: updateItemsData, message: 'updated' });
    } catch (error) {
      next(error);
    }
  };

  public deleteItems = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const itemsId: string = req.params.id;
      const deleteItemsData: Items = await this.itemsService.deleteItems(itemsId);

      res.status(200).json({ data: deleteItemsData, message: 'deleted' });
    } catch (error) {
      next(error);
    }
  };
}

export default ItemsController;
