import { NextFunction, Request, Response } from 'express';
import { CreateResourcesDto } from '../dtos/resources.dto';
import { Resources } from '../interfaces/resources.interface';
import resourcesService from '../services/resources.service';
import resourcesModel from '../models/resources.model';

class ResourcesController {
  public resourcesService = new resourcesService();

  public findAllResources = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const findAllResourcesData: Resources[] = await this.resourcesService.findAllResources();

      res.status(200).json({ data: findAllResourcesData, message: 'findAll' });
    } catch (error) {
      next(error);
    }
  };

  public findResourcesById = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const resourcesId: string = req.params.id;
      const findOneResourcesData: Resources = await this.resourcesService.findResourcesById(resourcesId);

      res.status(200).json({ data: findOneResourcesData, message: 'findOne' });
    } catch (error) {
      next(error);
    }
  };

  public findResourcesByLevel = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const level: string = req.params.level;

      const findResourcesData: Resources[] = await this.resourcesService.findResourcesByLevel(level);

      res.status(200).json({ data: findResourcesData, message: 'findOne' });
    } catch (error) {
      next(error);
    }
  };

  public createResources = async (req: Request, res: Response, next: NextFunction) => {
    try {
    const topic = req.body.topic;
    const details = req.body.details;
    const level = req.body.level;
   
    let newResources = new resourcesModel({
        topic, details, level
  })

      const createResourcesData: Resources = await this.resourcesService.createResources(newResources);

      res.status(201).json({ data: createResourcesData, message: 'created' });
    } catch (error) {
      next(error);
    }
  };

  public updateResources = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const id: string = req.params.id;
      const resourcesData: CreateResourcesDto = req.body;
      const updateResourcesData: Resources = await this.resourcesService.updateResources(id, resourcesData);

      res.status(200).json({ data: updateResourcesData, message: 'updated' });
    } catch (error) {
      next(error);
    }
  };

  public deleteResources = async (req: Request, res: Response, next: NextFunction) => {
    try {
      const id: string = req.params.id;
      const deleteResourcesData: Resources = await this.resourcesService.deleteResources(id);

      res.status(200).json({ data: deleteResourcesData, message: 'deleted' });
    } catch (error) {
      next(error);
    }
  };
}

export default ResourcesController;
