import { Router } from 'express';
import itemsController from '../controllers/items.controller';
import { CreateItemsDto } from '../dtos/items.dto';
import { Routes } from '../interfaces/routes.interface';
import validationMiddleware from '../middlewares/validation.middleware';
import multer from 'multer';
import { storage } from '../cloudinary/index.js';
const upload = multer({ storage });

class ItemsRoute implements Routes {
  public path = '/items';
  public router = Router();
  public itemsController = new itemsController();

  constructor() {
    this.initializeRoutes();
  }

  private initializeRoutes() {
    this.router.get(`${this.path}`, this.itemsController.findAllItems);
    this.router.get(`${this.path}/:id`, this.itemsController.findItemsById);
    this.router.get(`${this.path}//:resourcesId`, this.itemsController.findItemsByResourcesId);
    this.router.post(`${this.path}`, upload.single("image"), this.itemsController.createItems);
    this.router.put(`${this.path}/:id`, validationMiddleware(CreateItemsDto, 'body', true), this.itemsController.updateItems);
    this.router.delete(`${this.path}/:id`, this.itemsController.deleteItems);
  }
}

export default ItemsRoute;
