import { Router } from 'express';
import resourcesController from '../controllers/Resources.controller';
import { CreateResourcesDto } from '../dtos/resources.dto';
import { Routes } from '../interfaces/routes.interface';
import validationMiddleware from '../middlewares/validation.middleware';

class ResourcesRouteRoute implements Routes {
  public path = '/resources';
  public router = Router();
  public resourcesController = new resourcesController();

  constructor() {
    this.initializeRoutes();
  }

  private initializeRoutes() {
    this.router.get(`${this.path}`, this.resourcesController.findAllResources);
    this.router.get(`${this.path}/:id`, this.resourcesController.findResourcesById);
    this.router.get(`${this.path}//:level`, this.resourcesController.findResourcesByLevel);
    this.router.post(`${this.path}`, validationMiddleware(CreateResourcesDto, 'body'), this.resourcesController.createResources);
    this.router.put(`${this.path}/:id`, validationMiddleware(CreateResourcesDto, 'body', true), this.resourcesController.updateResources);
    this.router.delete(`${this.path}/:id`, this.resourcesController.deleteResources);
  }
}

export default ResourcesRouteRoute;
