import { HttpException } from '../exceptions/HttpException';
import { Games } from '@/interfaces/games.interface';
import gamesModel from '../models/games.model';
import { isEmpty } from '../utils/util';

class GamesService {

  public games = gamesModel;

  public async getUnlockGamesByLevel(level: string): Promise<Games[]> {
    if (isEmpty(level)) throw new HttpException(400, "expenseId is empty");

    const findGames: Games[] = await this.games.find({ level: level, status: 'U' });
    if (!findGames) throw new HttpException(409, "Expense doesn't exist");

    return findGames;
  }

  public async getLockGamesByLevel(level: string): Promise<Games[]> {
    if (isEmpty(level)) throw new HttpException(400, "expenseId is empty");

    const findGames: Games[] = await this.games.find({ level: level, status: 'L' });
    if (!findGames) throw new HttpException(409, "Expense doesn't exist");

    return findGames;
  }

  public async getGameById(id: string): Promise<Games> {
    const findGame: Games = await this.games.findOne({ _id: id});
    if (!findGame) throw new HttpException(409, "Expense doesn't exist");
    return findGame;
  }

  public async createGame(gameData: Games): Promise<Games> {
    if (isEmpty(gameData)) throw new HttpException(400, "expenseData is empty");
    const createGameData: Games = await this.games.create(gameData);
    return createGameData;
  }



  public async deleteGame(id: string): Promise<Games> {
    const deleteGameById: Games = await this.games.findByIdAndDelete(id);
    if (!deleteGameById) throw new HttpException(409, "Expense doesn't exist");

    return deleteGameById;
  }
}

export default GamesService;
