import { CreateItemsDto } from '../dtos/items.dto';
import { HttpException } from '../exceptions/HttpException';
import { Items } from '@/interfaces/items.interface';
import itemsModel from '../models/item.model';
import { isEmpty } from '../utils/util';

class ItemsService {

  public items = itemsModel;

  public async findAllItems(): Promise<Items[]> {
    const items: Items[] = await this.items.find();
    return items;
  }

  public async findItemsById(itemsId: string): Promise<Items> {
    if (isEmpty(itemsId)) throw new HttpException(400, "expenseId is empty");

    const findItem: Items = await this.items.findOne({ _id: itemsId });
    if (!findItem) throw new HttpException(409, "Expense doesn't exist");

    return findItem;
  }

  public async findItemsByResourcesId(resourcesId: string): Promise<Items[]> {
    const findItems: Items[] = await this.items.find({ resourcesId: resourcesId});
    if (!findItems) throw new HttpException(409, "Expense doesn't exist");
    return findItems;
  }

  public async createItems(ItemsData: Items): Promise<Items> {
    if (isEmpty(ItemsData)) throw new HttpException(400, "expenseData is empty");
    const createItemsData: Items = await this.items.create(ItemsData);
    return createItemsData;
  }

  public async updateItems(itemsId: string, itemsData: CreateItemsDto): Promise<Items> {
    if (isEmpty(itemsData)) throw new HttpException(400, "expenseData is empty");

    const updateItemsById: Items = await this.items.findByIdAndUpdate(itemsId,itemsData);
    if (!updateItemsById) throw new HttpException(409, "Expense doesn't exist");

    return updateItemsById;
  }

  public async deleteItems(itemsId: string): Promise<Items> {
    const deleteItemsById: Items = await this.items.findByIdAndDelete(itemsId);
    if (!deleteItemsById) throw new HttpException(409, "Expense doesn't exist");

    return deleteItemsById;
  }
}

export default ItemsService;
