import { CreateResourcesDto } from '../dtos/resources.dto';
import { HttpException } from '../exceptions/HttpException';
import { Resources } from '@/interfaces/resources.interface';
import resourcesModel from '../models/resources.model';
import { isEmpty } from '../utils/util';

class ResourcesService {

  public resources = resourcesModel;

  public async findAllResources(): Promise<Resources[]> {
    const resources: Resources[] = await this.resources.find();
    return resources;
  }

  public async findResourcesById(resourcesId: string): Promise<Resources> {
    if (isEmpty(resourcesId)) throw new HttpException(400, "expenseId is empty");

    const findResources: Resources = await this.resources.findOne({ _id: resourcesId });
    if (!findResources) throw new HttpException(409, "Expense doesn't exist");

    return findResources;
  }

  public async findResourcesByLevel(level: string): Promise<Resources[]> {
    const findResources: Resources[] = await this.resources.find({ level: level});
    if (!findResources) throw new HttpException(409, "Expense doesn't exist");
    return findResources;
  }

  public async createResources(resourcesData: Resources): Promise<Resources> {
    if (isEmpty(resourcesData)) throw new HttpException(400, "expenseData is empty");
    const createResourcesData: Resources = await this.resources.create(resourcesData);
    return createResourcesData;
  }

  public async updateResources(resourcesId: string, resourcesData: CreateResourcesDto): Promise<Resources> {
    if (isEmpty(resourcesData)) throw new HttpException(400, "expenseData is empty");

    const updateResourcesById: Resources = await this.resources.findByIdAndUpdate(resourcesId,resourcesData);
    if (!updateResourcesById) throw new HttpException(409, "Expense doesn't exist");

    return updateResourcesById;
  }

  public async deleteResources(resourcesId: string): Promise<Resources> {
    const deleteResourcesById: Resources = await this.resources.findByIdAndDelete(resourcesId);
    if (!deleteResourcesById) throw new HttpException(409, "Expense doesn't exist");

    return deleteResourcesById;
  }
}

export default ResourcesService;
